==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractJimpleIntLongBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractJimpleIntLongBinopExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr
// @dep_class 2edcd395b8ec24b3 soot_jimple_internal_AbstractJimpleIntLongBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractIntLongBinopExpr

#include "soot/jimple/internal/AbstractIntLongBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractJimpleIntLongBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractJimpleIntLongBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$refs	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtable	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods {
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object {
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractJimpleIntLongBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractJimpleIntLongBinopExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractJimpleIntLongBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractJimpleIntLongBinopExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr
// @dep_class 2edcd395b8ec24b3 soot_jimple_internal_AbstractJimpleIntLongBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractIntLongBinopExpr

#include "soot/jimple/internal/AbstractIntLongBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractJimpleIntLongBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractJimpleIntLongBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$refs	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtable	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods {
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$object {
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vtype _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractJimpleIntLongBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractJimpleIntLongBinopExpr_H_ */
